(window.webpackJsonp=window.webpackJsonp||[]).push([[0],{15:function(e,t,n){e.exports=n(25)},25:function(e,t,n){"use strict";n.r(t);var o=n(6),a=n.n(o),r=n(13),i=n.n(r),c=n(0),l=n(4),p=n(2),u=n(1),s=n(3),d=n(8),g=n(9),h=function(e){function t(){var e,n;Object(c.a)(this,t);for(var o=arguments.length,r=new Array(o),i=0;i<o;i++)r[i]=arguments[i];return(n=Object(p.a)(this,(e=Object(u.a)(t)).call.apply(e,[this].concat(r)))).render=function(){var e=n.props.args,t=e.title,o=e.text,r=e.image,i=n.props.theme;if(!i)return a.a.createElement("div",null,"Theme is undefined, please check streamlit version.");var c=g.a.div({display:"flex",cursor:"pointer",fontFamily:"".concat(i.font,", 'Segoe UI', 'Roboto', sans-serif"),height:"".concat(250,"px"),borderRadius:"20px",overflow:"hidden",backgroundImage:"url(".concat(r,")"),backgroundPosition:"center",backgroundSize:"cover",backgroundRepeat:"no-repeat",backgroundColor:"#eee",boxShadow:"0px 0px 40px rgba(0, 0, 0, 0.2)",margin:"".concat(40,"px"),flexDirection:"column",justifyContent:"center",alignItems:"center",textAlign:"center",color:i.textColor,width:"".concat(300,"px"),position:"relative",transition:"all 0.3s ease-in-out"},"\n      &:hover {\n        box-shadow: 0px 0px 40px rgba(0, 0, 0, 0.4);\n      }\n      &:active {\n        box-shadow: 0px 0px 40px rgba(0, 0, 0, 0.7);\n      }\n      "),l=g.a.div({height:330,width:380,margin:"auto"}),p=g.a.h2({color:"white",zIndex:"2",fontSize:"2em",fontWeight:"bolder"}),u=g.a.p({color:"white",fontWeight:"bolder",zIndex:"2",fontSize:"1em"}),s=g.a.div({backgroundColor:"rgba(0, 0, 0, 0.5)",height:"100%",width:"100%",position:"absolute",top:"0",left:"0",zIndex:"1"});return a.a.createElement(l,null,a.a.createElement(c,{onClick:n.onClick},a.a.createElement(s,null),a.a.createElement(p,null,t),a.a.createElement(u,null,o)))},n.onClick=function(){n.props.args.url&&window.open(n.props.args.url,"_blank"),d.a.setComponentValue(!0)},n}return Object(s.a)(t,e),Object(l.a)(t,[{key:"componentDidUpdate",value:function(){d.a.setFrameHeight()}},{key:"componentDidMount",value:function(){d.a.setFrameHeight()}}]),t}(d.b),b=Object(d.c)(h);i.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(b,null)),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.d3689c9d.chunk.js.map